summaryrefslogtreecommitdiffstats
path: root/chrome/browser/chromeos
diff options
context:
space:
mode:
authorjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-02 20:15:25 +0000
committerjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-02 20:15:25 +0000
commit4b19ea5f055ab1c822f9ab6d57c8db59212db395 (patch)
treea9613560881a8f5db6cbd0a478a4581d85145086 /chrome/browser/chromeos
parentcff06c5779f85713bc4b09ce110ec26544322d64 (diff)
downloadchromium_src-4b19ea5f055ab1c822f9ab6d57c8db59212db395.zip
chromium_src-4b19ea5f055ab1c822f9ab6d57c8db59212db395.tar.gz
chromium_src-4b19ea5f055ab1c822f9ab6d57c8db59212db395.tar.bz2
Replace the TabContents* accessors with WebContents* in InterstitialPage, BackgroundContents and NativeTabContentsContainer and update the related code.
BUG=98716 TBR=joi Review URL: http://codereview.chromium.org/9064002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@116108 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/chromeos')
-rw-r--r--chrome/browser/chromeos/offline/offline_load_page.cc7
-rw-r--r--chrome/browser/chromeos/offline/offline_load_page.h5
2 files changed, 6 insertions, 6 deletions
diff --git a/chrome/browser/chromeos/offline/offline_load_page.cc b/chrome/browser/chromeos/offline/offline_load_page.cc
index dabacb3..be8b22f 100644
--- a/chrome/browser/chromeos/offline/offline_load_page.cc
+++ b/chrome/browser/chromeos/offline/offline_load_page.cc
@@ -22,15 +22,16 @@
#include "chrome/common/extensions/extension.h"
#include "chrome/common/jstemplate_builder.h"
#include "chrome/common/url_constants.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/browser_thread.h"
#include "content/public/browser/notification_types.h"
+#include "content/public/browser/web_contents.h"
#include "grit/browser_resources.h"
#include "grit/generated_resources.h"
#include "ui/base/l10n/l10n_util.h"
#include "ui/base/resource/resource_bundle.h"
using content::BrowserThread;
+using content::WebContents;
namespace {
@@ -46,10 +47,10 @@ void SetString(DictionaryValue* strings, const char* name, int resource_id) {
namespace chromeos {
-OfflineLoadPage::OfflineLoadPage(TabContents* tab_contents,
+OfflineLoadPage::OfflineLoadPage(WebContents* web_contents,
const GURL& url,
OfflineResourceHandler* handler)
- : ChromeInterstitialPage(tab_contents, true, url),
+ : ChromeInterstitialPage(web_contents, true, url),
handler_(handler),
proceeded_(false),
ALLOW_THIS_IN_INITIALIZER_LIST(method_factory_(this)) {
diff --git a/chrome/browser/chromeos/offline/offline_load_page.h b/chrome/browser/chromeos/offline/offline_load_page.h
index 1271029..b17eb15 100644
--- a/chrome/browser/chromeos/offline/offline_load_page.h
+++ b/chrome/browser/chromeos/offline/offline_load_page.h
@@ -15,7 +15,6 @@
class Extension;
class OfflineResourceHandler;
-class TabContents;
namespace base {
class DictionaryValue;
@@ -30,8 +29,8 @@ namespace chromeos {
class OfflineLoadPage : public ChromeInterstitialPage,
public net::NetworkChangeNotifier::OnlineStateObserver {
public:
- // Create a offline load page for the |tab_contents|.
- OfflineLoadPage(TabContents* tab_contents, const GURL& url,
+ // Create a offline load page for the |web_contents|.
+ OfflineLoadPage(content::WebContents* web_contents, const GURL& url,
OfflineResourceHandler* handler);
protected: